@@ -2,7 +2,7 @@
 #
 # COPYRIGHT:
 #
-# This software is Copyright (c) 1996-2023 Best Practical Solutions, LLC
+# This software is Copyright (c) 1996-2024 Best Practical Solutions, LLC
 #                                          <sales@bestpractical.com>
 #
 # (Except where explicitly superseded by other copyright notices)
@@ -71,6 +71,8 @@ our %FIELD_METADATA = (
     Catalog          => [ 'ENUM' => 'Catalog', ], #loc_left_pair
     LastUpdated      => [ 'DATE'            => 'LastUpdated', ], #loc_left_pair
     Created          => [ 'DATE'            => 'Created', ], #loc_left_pair
+    Creator          => [ 'ENUM' => 'User', ], #loc_left_pair
+    LastUpdatedBy    => [ 'ENUM' => 'User', ], #loc_left_pair
 
     Linked           => [ 'LINK' ], #loc_left_pair
     LinkedTo         => [ 'LINK' => 'To' ], #loc_left_pair
@@ -90,6 +92,7 @@ our %FIELD_METADATA = (
     Contact          => [ 'WATCHERFIELD' => 'Contact', ], #loc_left_pair
     ContactGroup     => [ 'MEMBERSHIPFIELD' => 'Contact', ], #loc_left_pair
     CustomRole       => [ 'WATCHERFIELD' ], # loc_left_pair
+    Watcher          => [ 'WATCHERFIELD', ], #loc_left_pair
 
     CustomFieldValue => [ 'CUSTOMFIELD' => 'Asset' ], #loc_left_pair
     CustomField      => [ 'CUSTOMFIELD' => 'Asset' ], #loc_left_pair
@@ -396,7 +399,10 @@ sub AddRecord {
     my $asset = shift;
     return unless $asset->CurrentUserCanSee;
 
-    return if $asset->__Value('Status') eq 'deleted'
+    # No need to check "deleted" if it's from AssetSQL(_sql_query is set). This
+    # also short circuits Status check for RT::Report::Assets::Entry, which
+    # doesn't have Status column
+    return if !$self->{_sql_query} and $asset->__Value('Status') eq 'deleted'
         and not $self->{'allow_deleted_search'};
 
     $self->SUPER::AddRecord($asset, @_);
@@ -1932,6 +1938,11 @@ sub _ProcessRestrictions {
 
 }
 
+sub CurrentUserCanSeeAll {
+    my $self = shift;
+    return $self->CurrentUser->HasRight( Right => 'ShowAsset', Object => RT->System ) ? 1 : 0;
+}
+
 1;
 
 RT::Base->_ImportOverlays();
