@@ -2,7 +2,7 @@
 #
 # COPYRIGHT:
 #
-# This software is Copyright (c) 1996-2022 Best Practical Solutions, LLC
+# This software is Copyright (c) 1996-2024 Best Practical Solutions, LLC
 #                                          <sales@bestpractical.com>
 #
 # (Except where explicitly superseded by other copyright notices)
@@ -57,7 +57,7 @@ RT::Authen::ExternalAuth - RT Authentication using External Sources
 This module provides the ability to authenticate RT users against one or
 more external data sources at once. It will also allow information about
 that user to be loaded from the same, or any other available, source as
-well as allowing multple redundant servers for each method.
+well as allowing multiple redundant servers for each method.
 
 The functionality currently supports authentication and information from
 LDAP via the Net::LDAP module, and from any data source that an
@@ -419,7 +419,8 @@ sub DoAuth {
 
         # Does user already exist internally to RT?
         $session->{'CurrentUser'} = RT::CurrentUser->new();
-        $session->{CurrentUser}->LoadByCols( $field || 'Name', $username );
+        my $user = LoadUserObject( Field => $field || 'Name', Value => $username );
+        $session->{'CurrentUser'}->Load( $user->Id ) if $user->Id;
 
         # Unless we have loaded a valid user with a UserID create one.
         unless ($session->{'CurrentUser'}->Id) {
@@ -556,8 +557,7 @@ sub UpdateUserInfo {
 
     my $user_disabled   = RT::Authen::ExternalAuth::UserDisabled($username);
 
-    my $UserObj = RT::User->new(RT->SystemUser);
-    $UserObj->LoadByCols($field => $username);
+    my $UserObj = LoadUserObject( Field => $field, Value => $username, );
 
     # If user is disabled, set the RT::Principal to disabled and return out of the function.
     # I think it's a waste of time and energy to update a user's information if they are disabled
@@ -758,6 +758,30 @@ sub AddCustomFieldValue {
     return;
 }
 
+sub LoadUserObject {
+    my %args = (
+        Field => 'Name',
+        Value => undef,
+        @_
+    );
+    my ( $ret, $msg );
+
+    my $user = RT::User->new( RT->SystemUser );
+    if ( my ($cf_name) = $args{'Field'} =~ /^UserCF\.(.+)$/i ) {
+        ( $ret, $msg ) = $user->LoadByCustomFieldValue(
+            CustomField => $cf_name,
+            Value       => $args{'Value'},
+        );
+    }
+    else {
+        # No user CF, normal load
+        ( $ret, $msg ) = $user->LoadByCols( $args{'Field'}, $args{'Value'} );
+    }
+
+    RT->Logger->debug( "Unable to load user " . $args{'Value'} . " from field " . $args{'Field'} ) unless $ret;
+    return $user;
+}
+
 RT::Base->_ImportOverlays();
 
 1;
