@@ -2,7 +2,7 @@
 #
 # COPYRIGHT:
 #
-# This software is Copyright (c) 1996-2021 Best Practical Solutions, LLC
+# This software is Copyright (c) 1996-2024 Best Practical Solutions, LLC
 #                                          <sales@bestpractical.com>
 #
 # (Except where explicitly superseded by other copyright notices)
@@ -75,7 +75,7 @@ incoming email.
 
 =head1 CONFIGURATION
 
-There are two reveant configuration options, both of which are hashes:
+There are two relevant configuration options, both of which are hashes:
 C<GnuPG> and C<GnuPGOptions>. The first one controls RT specific
 options; it enables you to enable/disable the GPG protocol or change the
 format of messages. The second one is a hash with options which are
@@ -94,6 +94,18 @@ Set to true value to enable this subsystem:
         ... other options ...
     );
 
+=head3 Setting the GnuPG Command
+
+By default, RT looks for a command named C<gpg> in your C<$PATH> to run GnuPG.
+If the command has a different name or is outside the C<$PATH> on your system,
+you can specify the full path of the GnuPG command using the C<GnuPG> option:
+
+    Set( %GnuPG,
+        Enable => 1,
+        GnuPG  => '/usr/local/bin/gpg2',
+        ... other options ...
+    );
+
 =head3 Format of outgoing messages
 
 The format of outgoing messages can be controlled using the
@@ -148,8 +160,8 @@ default.
 =head2 %GnuPGOptions
 
 Use this hash to set additional options of the 'gnupg' program.  The
-only options which are diallowed are options which alter the output
-format or attempt to run commands; thiss includes C<--sign>,
+only options which are disallowed are options which alter the output
+format or attempt to run commands; this includes C<--sign>,
 C<--list-options>, etc.
 
 Some GnuPG options take arguments, while others take none. (Such as
@@ -196,7 +208,7 @@ add the C<--no-permission-warning> option to C<GnuPGOptions>.
 
 This option is required when the C<RFC> format for outgoing messages is
 used.  RT defaults to 'SHA1' by default, but you may wish to override
-it.  C<gnupng --version> will list the algorithms supported by your
+it.  C<gnupg --version> will list the algorithms supported by your
 C<gnupg> installation under 'hash functions'; these generally include
 MD5, SHA1, RIPEMD160, and SHA256.
 
@@ -229,8 +241,8 @@ default. As an administrative user of RT, open 'Admin' then 'Queues',
 and select a queue. On the page you can see information about the queue's keys 
 at the bottom and two checkboxes to choose default actions.
 
-As well, encryption is enabled for autoreplies and other notifications when
-an encypted message enters system via mailgate interface even if queue's
+As well, encryption is enabled for auto-replies and other notifications when
+an encrypted message enters system via mailgate interface even if queue's
 option is disabled.
 
 =head2 Encrypting to untrusted keys
@@ -831,6 +843,9 @@ sub FindScatteredParts {
         my $fname = $part->head->recommended_filename || '';
         next unless $fname =~ /\.(?:$file_extension_regex)$/;
 
+        # skip pgp keys, which could have .asc file extension
+        next if ( $part->head->mime_type // '' ) eq 'application/pgp-keys';
+
         $RT::Logger->debug("Found encrypted attachment '$fname'");
 
         $args{'Skip'}{$part} = 1;
@@ -992,7 +1007,7 @@ sub VerifyRFC3156 {
     my %args = ( Data => undef, Signature => undef, @_ );
 
     my ($tmp_fh, $tmp_fn) = File::Temp::tempfile( UNLINK => 1 );
-    binmode $tmp_fh, ':raw:eol(CRLF?)';
+    binmode $tmp_fh, ':raw:eol(CRLF)';
     $args{'Data'}->print( $tmp_fh );
     $tmp_fh->flush;
 
@@ -1043,7 +1058,7 @@ sub DecryptRFC3156 {
 
     seek $tmp_fh, 0, 0;
     my $parser = RT::EmailParser->new();
-    my $decrypted = $parser->ParseMIMEEntityFromFileHandle( $tmp_fh, 0 );
+    my $decrypted = $parser->ParseMIMEEntityFromFileHandle( $tmp_fh, 0, 1 );
     $decrypted->{'__store_link_to_object_to_avoid_early_cleanup'} = $parser;
 
     $args{'Top'}->parts( [$decrypted] );
