@@ -2,7 +2,7 @@
 #
 # COPYRIGHT:
 #
-# This software is Copyright (c) 1996-2023 Best Practical Solutions, LLC
+# This software is Copyright (c) 1996-2024 Best Practical Solutions, LLC
 #                                          <sales@bestpractical.com>
 #
 # (Except where explicitly superseded by other copyright notices)
@@ -193,7 +193,7 @@ sub ApplySortOrder {
 =head2 LimitToNotAdded
 
 Takes either list of object ids or nothing. Limits collection
-to custom roles to listed objects or any corespondingly.
+to custom roles to listed objects or any correspondingly.
 
 =cut
 
@@ -204,7 +204,7 @@ sub LimitToNotAdded {
 
 =head2 LimitToAdded
 
-Limits collection to custom roles to listed objects or any corespondingly.
+Limits collection to custom roles to listed objects or any correspondingly.
 
 =cut
 
@@ -213,6 +213,12 @@ sub LimitToAdded {
     return RT::ObjectCustomRoles->new( $self->CurrentUser )->LimitTargetToAdded( $self => @_ );
 }
 
+sub CurrentUserCanSeeAll {
+    my $self = shift;
+    # Not typo, user needs SeeQueue to see CustomRoles
+    return $self->CurrentUser->HasRight( Right => 'SeeQueue', Object => RT->System ) ? 1 : 0;
+}
+
 RT::Base->_ImportOverlays();
 
 1;
