@@ -2,7 +2,7 @@
 #
 # COPYRIGHT:
 #
-# This software is Copyright (c) 1996-2015 Best Practical Solutions, LLC
+# This software is Copyright (c) 1996-2024 Best Practical Solutions, LLC
 #                                          <sales@bestpractical.com>
 #
 # (Except where explicitly superseded by other copyright notices)
@@ -52,7 +52,7 @@ use warnings;
 
 use DateTime;
 
-require UNIVERSAL::require;
+use RT::StaticUtil;
 my %Meta = (
     DatabaseType => {
         Widget          => '/Widgets/Form/Select',
@@ -61,7 +61,7 @@ my %Meta = (
             Values      => [
                 grep {
                     my $m = 'DBD::' . $_;
-                    $m->require ? 1 : 0
+                    RT::StaticUtil::RequireModule($m) ? 1 : 0
                   } qw/mysql Pg SQLite Oracle/
             ],
             ValuesLabel => {
@@ -131,12 +131,6 @@ my %Meta = (
             Hints       => 'The password RT should use to connect to the database.',
         },
     },
-    DatabaseRequireSSL => {
-        Widget          => '/Widgets/Form/Boolean',
-        WidgetArguments => {
-            Description => 'Use SSL?',    # loc
-        },
-    },
     rtname => {
         Widget          => '/Widgets/Form/String',
         WidgetArguments => {
@@ -288,7 +282,9 @@ sub SaveConfig {
             # remove obsolete settings we'll add later
             $content =~ s/^\s* Set \s* \( \s* \$$_ .*$//xm;
 
-            $content .= "Set( \$$_, '$RT::Installer->{InstallConfig}{$_}' );\n";
+            my $value = $RT::Installer->{InstallConfig}{$_};
+            $value =~ s/(['\\])/\\$1/g;
+            $content .= "Set( \$$_, '$value' );\n";
         }
         $content .= "1;\n";
         print $fh $content;
@@ -304,7 +300,7 @@ sub SaveConfig {
 
     RT::Installer - RT's Installer
 
-=head1 SYNOPSYS
+=head1 SYNOPSIS
 
     use RT::Installer;
     my $meta = RT::Installer->Meta;
