@@ -2,7 +2,7 @@
 #
 # COPYRIGHT:
 #
-# This software is Copyright (c) 1996-2023 Best Practical Solutions, LLC
+# This software is Copyright (c) 1996-2024 Best Practical Solutions, LLC
 #                                          <sales@bestpractical.com>
 #
 # (Except where explicitly superseded by other copyright notices)
@@ -569,6 +569,17 @@ sub CanonicalizeAttributes {
                         $record->{Content}{StackedGroupBy} = $stacked_group_by if $stacked_group_by;
                     }
                 }
+                elsif ( $record->{Name} eq 'CustomFieldDefaultValues' ) {
+                    my %value;
+                    for my $id ( keys %{ $record->{Content} || {} } ) {
+                        my $custom_field = RT::CustomField->new( RT->SystemUser );
+                        $custom_field->Load($id);
+                        if ( $custom_field->Id ) {
+                            $value{ $custom_field->Name } = $record->{Content}{$id};
+                        }
+                    }
+                    $record->{Content} = \%value;
+                }
             }
         }
         elsif ( $record->{Name} =~ /DefaultDashboard$/ ) {
