@@ -2,7 +2,7 @@
 #
 # COPYRIGHT:
 #
-# This software is Copyright (c) 1996-2021 Best Practical Solutions, LLC
+# This software is Copyright (c) 1996-2024 Best Practical Solutions, LLC
 #                                          <sales@bestpractical.com>
 #
 # (Except where explicitly superseded by other copyright notices)
@@ -308,16 +308,16 @@ sub Roles {
              map { [ $_, $self->_ROLES->{$_} ] }
             keys %{ $self->_ROLES };
 
-    # Cache at ticket/queue object level mainly to reduce calls of
-    # custom role's AppliesToObjectPredicate for performance.
-    if ( ref($self) =~ /RT::(?:Ticket|Queue)/ ) {
+    # Cache at object level mainly to reduce calls of custom role's
+    # AppliesToObjectPredicate for performance.
+    if ( ref($self) =~ /RT::(?:Ticket|Queue|Asset|Catalog)/ ) {
         $self->{_Roles}{$key} = \@roles;
     }
     return @roles;
 }
 
 {
-    my %ROLES;
+    our %ROLES;
     sub _ROLES {
         my $class = ref($_[0]) || $_[0];
         return $ROLES{$class} ||= {};
@@ -405,24 +405,14 @@ The Name of an L<RT::Group>.
 
 sub CanonicalizePrincipal {
     my $self = shift;
-    my %args = (@_);
+    my %args = (ExcludeRTAddress => 1, @_);
 
     return (0, $self->loc("One, and only one, of Principal/PrincipalId/User/Group is required"))
         if 1 != grep { $_ } @args{qw/Principal PrincipalId User Group/};
 
-    if ($args{Principal}) {
-        return $args{Principal};
-    }
-    elsif ($args{PrincipalId}) {
-        # Check the PrincipalId for loops
-        my $principal = RT::Principal->new( $self->CurrentUser );
-        $principal->Load($args{'PrincipalId'});
-        if ( $principal->id and $principal->IsUser and my $email = $principal->Object->EmailAddress ) {
-            return (0, $self->loc("[_1] is an address RT receives mail at. Adding it as a '[_2]' would create a mail loop",
-                                  $email, $self->loc($args{Type})))
-                if RT::EmailParser->IsRTAddress( $email );
-        }
-    } else {
+    $args{PrincipalId} = $args{Principal}->Id if $args{Principal};
+
+    if ( !$args{PrincipalId} ) {
         if ( ( $args{User} || '' ) =~ /^\s*group\s*:\s*(\S.*?)\s*$/i ) {
             $args{Group} = $1;
             delete $args{User};
@@ -433,7 +423,7 @@ sub CanonicalizePrincipal {
             # Sanity check the address
             return (0, $self->loc("[_1] is an address RT receives mail at. Adding it as a '[_2]' would create a mail loop",
                                   $name, $self->loc($args{Type}) ))
-                if RT::EmailParser->IsRTAddress( $name );
+                if $args{ExcludeRTAddress} && RT::EmailParser->IsRTAddress( $name );
 
             # Create as the SystemUser, not the current user
             my $user = RT::User->new(RT->SystemUser);
@@ -465,6 +455,20 @@ sub CanonicalizePrincipal {
     my $principal = RT::Principal->new( $self->CurrentUser );
     $principal->Load( $args{PrincipalId} );
 
+    if (    $args{ExcludeRTAddress}
+        and $principal->Id
+        and $principal->IsUser
+        and my $email = $principal->Object->EmailAddress )
+    {
+        return (
+            0,
+            $self->loc(
+                "[_1] is an address RT receives mail at. Adding it as a '[_2]' would create a mail loop",
+                $email, $self->loc( $args{Type} )
+            )
+        ) if RT::EmailParser->IsRTAddress($email);
+    }
+
     return $principal;
 }
 
@@ -570,7 +574,7 @@ sub DeleteRoleMember {
     return (0, $self->loc("That role is invalid for this object"))
         unless $args{Type} and $self->HasRole($args{Type});
 
-    my ($principal, $msg) = $self->CanonicalizePrincipal(%args);
+    my ($principal, $msg) = $self->CanonicalizePrincipal(%args, ExcludeRTAddress => 0);
     return (0, $msg) if !$principal;
 
     my $acl = delete $args{ACL};
@@ -847,4 +851,48 @@ you see faster create times.
 
 =cut
 
+=head2 CustomRoleObj
+
+Returns the L<RT::CustomRole> object for this role if and only if it's
+backed by a custom role. If it's a core role (e.g. Ticket Requestors),
+returns C<undef>.
+
+=cut
+
+sub CustomRoleObj {
+    my $self = shift;
+    my $name = shift;
+
+    if (my ($id) = $name =~ /^RT::CustomRole-(\d+)$/) {
+        my $role = RT::CustomRole->new($self->CurrentUser);
+        my ( $ret, $msg ) = $role->Load($id);
+        if ( $ret ) {
+            return $role;
+        }
+        else {
+            RT->Logger->warning("Couldn't load custom role #$id: $msg");
+        }
+    }
+
+    return undef;
+}
+
+
+=head2 RoleAddresses
+
+Takes a role name and returns a string of all the email addresses for
+users in that role.
+
+=cut
+
+sub RoleAddresses {
+    my $self = shift;
+    my $role = shift;
+
+    if ( $self->CurrentUserCanSee ) {
+        return $self->RoleGroup($role)->MemberEmailAddressesAsString;
+    }
+    return undef;
+}
+
 1;
